@@ -1,13 +1,13 @@
 """Store the classes and fixtures used throughout the tests."""
 
 import os
+from pathlib import Path
 from typing import Any, Dict, Generator
 
 import boto3
 import pytest
 from moto import mock_autoscaling, mock_ec2, mock_iam, mock_rds, mock_route53, mock_s3
-from py._path.local import LocalPath
-from repository_orm import FakeRepository
+from repository_orm import FakeRepository, TinyDBRepository
 
 from clinv.adapters.fake import FakeSource
 from clinv.config import Config
@@ -28,15 +28,13 @@ def fixture_config(db_tinydb: str) -> Config:
 
 
 @pytest.fixture(name="db_tinydb")
-def db_tinydb_(tmpdir: LocalPath) -> str:
+def db_tinydb_(tmp_path: Path) -> str:
     """Create the TinyDB database url.
 
     Returns:
         database_url: Url used to connect to the database.
     """
-    # ignore: Call of untyped join function in typed environment.
-    # Until they give typing information there is nothing else to do.
-    tinydb_file_path = str(tmpdir.join("tinydb.db"))  # type: ignore
+    tinydb_file_path = str(tmp_path / "tinydb.db")
 
     tinydb_url = f"tinydb:///{tinydb_file_path}"
 
@@ -56,6 +54,16 @@ def repo_() -> Generator[FakeRepository, None, None]:
     repo.close()
 
 
+@pytest.fixture(name="repo_tinydb")
+def repo_tinydb_(db_tinydb: str) -> Generator[TinyDBRepository, None, None]:
+    """Configure a TinyDBRepository instance"""
+    repo = TinyDBRepository(db_tinydb)
+
+    yield repo
+
+    repo.close()
+
+
 @pytest.fixture(name="source")
 def source_() -> FakeSource:
     """Configure a FakeSource instance."""
@@ -82,6 +90,8 @@ def ec2_(_aws_credentials: None) -> Any:
 @pytest.fixture(name="rds")
 def rds_(_aws_credentials: None) -> Any:
     """Configure the boto3 RDS client."""
+    # Until https://github.com/boto/botocore/issues/2705 is closed
+    os.environ["BOTO_DISABLE_COMMONNAME"] = "true"
     with mock_rds():
         yield boto3.client("rds", region_name="us-east-1")
 
