@@ -1,12 +1,13 @@
 """Tests the service layer."""
 
 import pytest
-from repository_orm import FakeRepository, Repository
+from repository_orm import EntityNotFoundError, FakeRepository, Repository
 from tests.factories import (
     EC2Factory,
     IAMGroupFactory,
     PersonFactory,
     ProjectFactory,
+    SecurityGroupFactory,
     ServiceFactory,
 )
 
@@ -104,6 +105,25 @@ class TestSearch:
 
         assert found_entities == [entity]
 
+    def test_searching_by_security_groups_does_not_raise_error(
+        self, repo_tinydb: Repository
+    ) -> None:
+        """
+        Given: A security group
+        When: searching for a string
+        Then: it doesn't return an error
+
+        Until https://github.com/lyz-code/repository-orm/issues/15 is fixed we can't
+        search by the egress and ingress of the security groups
+        """
+        repo = repo_tinydb
+        entity = SecurityGroupFactory.build()
+        repo.add(entity)
+        repo.commit()
+
+        with pytest.raises(EntityNotFoundError):
+            list(search(repo, "test", resource_types=["sg"]))
+
 
 class TestUnused:
     """Test the unused service implementation."""
@@ -125,6 +145,23 @@ class TestUnused:
         assert len(result) == 1
         assert result == [service]
 
+    def test_unused_detects_unused_stopped_resources(
+        self,
+        repo: Repository,
+    ) -> None:
+        """
+        Given: One service that is not used by any other resource
+        When: unused is called.
+        Then: the service is returned.
+        """
+        service = repo.add(ServiceFactory.build(state="stopped"))
+        repo.commit()
+
+        result = unused(repo)
+
+        assert len(result) == 1
+        assert result == [service]
+
     @pytest.mark.parametrize(
         "entity",
         [
